@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4102';
+our $VERSION = '0.4103';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -438,16 +438,14 @@ sub pattern {
         1 => sub { $self->note( $args{duration}, $args{instrument} ) },
     };
 
-    set_chan_patch( $self->score, $self->channel, $args{instrument} );
-
     for my $pattern (@{ $args{patterns} }) {
-        next if $pattern =~ /^0+$/;
-
         $pattern =~ tr/01/10/ if $args{negate};
 
+        next if $pattern =~ /^0+$/;
+
         for ( 1 .. $args{repeat} ) {
             for my $bit ( split //, $pattern ) {
-                $args{vary}{$bit}->($self);
+                $args{vary}{$bit}->($self, %args);
             }
         }
     }
@@ -622,7 +620,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4102
+version 0.4103
 
 =head1 SYNOPSIS
 
